from random import choice
from supportive_functions import generate_female_name, generate_male_name


female_prefix = [
    "agá", "aléx", "amphí", "aná", "arí", "athén", "démé", "élektr", "eurydí", "euthén", "galát",
    "harmón", "hébé", "hér", "kalí", "kleió", "kyprí", "lét", "méliss", "nér", "orestí", "pandór",
    "penél", "perí", "philómél", "pó", "thál", "théod", "xén"
]
female_suffix = [
    "a", "anthe", "dóra", "eia", "éne", "essa", "ia", "idóra", "ika", "inia", "ipé", "ithéa", "íne",
    "ita", "oé", "óra", "otea", "óti", "oula", "phén", "phíne", "phrón", "séa", "théa", "théne",
    "tía", "tra", "tía", "ydia"
]

male_prefix = [
    'aeg', 'aer', 'alex', 'amph', 'an', 'anat', 'and', 'ant', 'arch', 'arist', 'astr', 'calli', 'chr',
    'chrys', 'cle', 'cyr', 'dam', 'dem', 'dion', 'eir', 'eugen', 'euph', 'her', 'herm', 'hip', 'hipp',
    'kal', 'klei', 'leon', 'lys', 'megas', 'myr', 'neo', 'nik', 'olym', 'pan', 'per', 'phil', 'pho',
    'pol', 'pyth', 'soph', 'theo', 'theod', 'xan', 'xen', 'zen'
]

male_suffix = [
    'ades', 'ander', 'archos', 'as', 'asios', 'ax', 'axos', 'eides', 'enios', 'eochos', 'eokles', 'eon',
    'eris', 'es', 'ias', 'ides', 'ikles', 'ion', 'ios', 'is', 'kleis', 'kles', 'kriti', 'lon', 'lykos',
    'medes', 'mon', 'mos', 'on', 'or', 'oris', 'os', 'otes', 'otis', 'ox', 'oxenos', 'oxis', 'pheles',
    'phoros', 'ptolemeos', 'rakles', 'ros', 'ruthios', 'sthenes', 'stratos', 'teles', 'tides', 'tor',
    'us', 'xander', 'xandros', 'xenos', 'xion', 'xiphos', 'ylos', 'zenos'
]

surnames = [
    "the Wise", "the Philosopher", "the Brave", "the Just", "the Noble", "the Bold", "the Merciful",
    "the Pious", "the Virtuous", "the Fierce", "the Strong", "the Loyal", "the Courageous", "the Valiant",
    "the Resolute", "the Magnificent", "the Majestic", "the Tranquil", "the Radiant", "the Serene",
    "the Wise", "the Enlightened", "the Gifted", "the Brilliant", "the Learned", "the Scholar",
    "the Thoughtful", "the Humble", "the Modest", "the Generous", "the Gracious", "the Benevolent",
    "the Compassionate", "the Kind", "the Gentle", "the Peaceful", "the Serene", "the Harmonious",
    "the Charismatic", "the Charming", "the Enigmatic", "the Joyful", "the Optimistic", "the Cheerful",
    "the Melancholy", "the Mysterious", "the Witty", "the Clever", "the Skilled", "the Agile",
    "the Swift", "the Resilient", "the Tenacious", "the Wise", "the Visionary", "the Inventive",
    "the Curious", "the Diligent", "the Persevering", "the Resourceful", "the Ambitious", "the Daring",
    "the Fearless", "the Audacious", "the Intrepid", "the Majestic", "the Regal", "the Commanding",
    "the Supreme", "the Exalted", "the Sovereign", "the Mighty", "the Unyielding", "the Victorious",
    "the Glorious", "the Triumphant", "the Magnanimous", "the Golden", "the Divine", "the Eternal",
    "the Everlasting", "the Radiant", "the Splendid", "the Enchanting", "the Eloquent", "the Graceful",
    "the Elegant", "the Stalwart", "the Sturdy", "the Honorable", "the Devoted", "the Revered",
    "the Heroic", "the Legendary", "the Illustrious", "the Renowned", "the Celebrated", "the Great",
    "the Grand", "the Mighty", "the Colossal", "the Monumental", "the Monumentous", "the Illustrious",
    "the Eminent", "the Venerable",
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = choice(surnames)



from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "cer", "cy", "dan", "el", "es", "fi", "gwen", "is", "jil", "ka", "la", "me", "nes", "phi", "que",
    "ri", "sha", "tri", "va", "wen", "xi", "ya", "zel"
]


female_suffix = [
    "a", "anna", "ara", "delle", "ena", "eth", "felle", "ia", "in", "is", "la", "mina", "na", "nara",
    "ne", "neth", "ra", "re", "ri", "selle", "sha", "thel", "tri", "va", "vera", "wyn", "ya", "zara"
]

male_prefix = [
    "al", "ar", "ber", "cor", "dan", "ed", "fer", "gar", "hal", "ian", "jar", "kar", "luc",
    "mar", "nor", "or", "per", "quil", "rad", "ser", "ter", "ul", "val", "wal", "xan", "yar",
    "zan"
]

male_suffix = [
    "an", "ard", "en", "er", "ian", "ion", "is", "ix", "le", "lin", "mir", "on", "or", "rick",
    "ton", "us", "ven", "ver", "wick", "win", "xander", "yen", "yson", "zeb", "zen"
]


surname_prefix = [
    "ber", "car", "dor", "ev", "fal", "ger", "han", "iar", "jor", "kal", "lin", "mor", "nar",
    "oer", "per", "qar", "ran", "sar", "tor", "ud", "var", "wer", "xan", "yor", "zar"
]

# Harry Potter-based surname suffixes
surname_suffix = [
    "dith", "elle", "fain", "gwen", "hild", "is", "jenn", "kath", "lith", "min", "na", "orin",
    "phine", "quil", "rin", "sael", "thel", "uin", "veth", "wyn", "xel", "yra", "zire"
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)



from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "aisha", "amal", "asra", "bahia", "dalila", "esma", "fadia", "ghada", "hala", "jalila",
    "kamila", "laila", "maha", "nadia", "omaira", "rabia", "sabah", "tamara", "yasmin", "zahra"
]

female_suffix = [
    "a", "ah", "at", "aya", "een", "ela", "ena", "era", "eya", "ia", "ida", "ina", "ira", "iya",
    "iyya", "iya", "iya", "iza", "ra", "ya"
]

male_prefix = [
    "ab", "ad", "ah", "al", "am", "an", "ar", "as", "az", "bah", "dal", "fah", "gha", "hab", "hak",
    "han", "has", "hay", "ibn", "id", "is", "ja", "kal", "kar", "kas", "lab", "mal", "mar", "nas",
    "rab", "rah", "sal", "sam", "sar", "sha", "tab", "tal", "tar", "yah", "yas", "zah", "zay"
]

male_suffix = [
    "ad", "ah", "al", "am", "an", "ar", "as", "at", "ay", "az", "dil", "din", "eem", "el", "en",
    "es", "ey", "id", "il", "im", "in", "ir", "is", "it", "iy", "iz", "lil", "mal", "mil", "min",
    "mir", "nir", "or", "os", "ur", "us", "ut", "uz"
]

surname_prefix =  [
    "abd", "al", "am", "an", "ar", "ash", "asim", "az", "bah", "dal", "fah", "ghal", "ham", "has", 
    "ibn", "jah", "kal", "kas", "mah", "naj", "qas", "ram", "saf", "sal", "sam", "tah", "zar"
]

surname_suffix = [
    "a", "ah", "at", "ay", "een", "i", "ia", "id", "il", "im", "ir", "is", "iy", "iyah", "ullah", 
    "ulah", "ur", "us", "ush", "yah", "yid", "yim", "yin"
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)


from supportive_functions import generate_female_name, generate_male_name, generate_surname_less


female_prefix = [
    "ada", "al", "am", "an", "bel", "beth", "ca", "ce", "cha", "da", "de", "dra", "ela", "el", "ema",
    "en", "fa", "fay", "ga", "ge", "gi", "ha", "he", "hi", "ila", "il", "ima", "in", "ja", "je", "ka",
    "ke", "ki", "la", "le", "li", "ma", "me", "mi", "na", "ne", "ni", "ola", "ol", "oma", "pa", "pe",
    "pi", "qua", "ra", "re", "ri", "sa", "se", "sha", "ta", "te", "tha", "u", "va", "ve", "vi", "wa",
    "we", "wi", "ya", "ye", "yi", "za", "ze", "zi"
]

female_suffix = [
    "a", "ana", "ara", "beth", "ca", "cel", "cia", "da", "dora", "e", "ella", "fa", "fay", "ga", "gine",
    "ha", "hilda", "ia", "ina", "ira", "la", "lina", "lissa", "ma", "mia", "na", "ne", "nia", "nissa",
    "ola", "ona", "ora", "pa", "pia", "ra", "ria", "rina", "sa", "sina", "sta", "ta", "tia", "trina",
    "va", "via", "vina", "wa", "wena", "wilda", "ya", "yna", "yra", "za", "zia", "zina"
]

male_prefix = [
    "al", "ar", "ben", "cor", "dan", "el", "fin", "gar", "hir", "ian", "jam", "kil", "lin",
    "mor", "nix", "or", "per", "quin", "ron", "sam", "ter", "ul", "ver", "wes", "xan", "yor",
    "zach"
]

male_suffix = [
    "ald", "bert", "cor", "dard", "el", "finn", "gald", "hart", "ian", "jack", "kyle", "land",
    "mack", "nald", "orin", "paul", "quin", "rick", "sam", "tin", "ulph", "vald", "wick", "xander",
    "yor", "zeph"
]

surname_prefix = [
    'amber', 'ash', 'beech', 'birch', 'black', 'bramble', 'bright', 'cedar', 'cypress','dark', 'ebony',
    'ember', 'fern', 'fire', 'glen', 'gold', 'hallow', 'hazel', 'holly', 'ivy', 'juniper', 'larch',
    'maple', 'moon', 'noble', 'oak', 'pine', 'proud', 'raven', 'rowan', 'sequoia', 'shadow', 'silver',
    'snow', 'spruce', 'star', 'stone', 'storm', 'swift', 'thistle', 'thorn', 'violet', 'willow', 'yew'
]

# Harry Potter-based surname suffixes
surname_suffix = [
    'ash', 'blaze', 'blossom', 'branch', 'breeze', 'brook', 'dawn', 'dusk', 'fall', 'feather', 'flame',
    'forest', 'glade', 'glimmer', 'glimpse', 'gust', 'heart', 'leaf', 'light', 'mist', 'moon', 'petal',
    'quill', 'ray', 'rose', 'shade', 'shimmer', 'song', 'spell', 'star', 'sun', 'thorn', 'twilight',
    'vale', 'whisper', 'wind', 'wisp', 'wood', 'wraith', 'wren'
]

female = generate_female_name(female_prefix, female_suffix, min=0, max=1)
male = generate_male_name(male_prefix, male_suffix, min=0, max=1)
surname = generate_surname_less(surname_prefix, surname_suffix)



from supportive_functions import generate_female_name, generate_male_name, generate_surname


female_prefix = [
    "ael", "al", "an", "ar", "cal", "dael", "el", "er", "fae", "fal", "fi", "gal", "gil", "glor",
    "hal", "ia", "id", "il", "im", "in", "laer", "lan", "leg", "li", "lind", "lith", "lor", "mae",
    "mel", "na", "nar", "nen", "ner", "or", "pe", "ran", "rhov", "sae", "saer", "se", "sil", "ta",
    "thal", "thar", "thing", "ti", "tir", "val", "ví", "yar", "zeph", "zim"
]

female_suffix = [
    "á", "ë", "í", "ír", "ís", "ith", "lá", "lé", "liël", "lís", "lith", "lyn", "má", "më", "mí",
    "ná", "në", "niël", "nis", "nith", "nyá", "rá", "ré", "riël", "ris", "rith", "ryá", "sä", "së",
    "siél", "sis", "sith", "stá", "thél", "theá", "thée", "thiël", "this", "thith", "vyl", "wén",
    "wiel", "wis", "withë", "yá", "yë", "yra", "ysë"
]

male_prefix = [
    "aeg", "aer", "am", "an", "ar", "bar", "ber", "cal", "cel", "cor", "dan", "dar", "den",
    "dor", "el", "em", "en", "er", "fal", "fer", "gal", "gar", "gil", "glor", "hal", "har",
    "hel", "her", "iath", "im", "in", "ir", "lam", "lar", "len", "lin", "lor", "mel", "men",
    "mir", "nem", "ner", "nim", "nor", "ol", "or", "rad", "ral", "ran", "rel", "rim", "ron",
    "sam", "san", "ser", "sil", "sin", "sor", "tan", "tar", "tel", "thor", "tom", "tor", "ul",
    "ur", "val", "var", "vén", "ver", "wil", "win", "wis", "yam", "yar", "ÿer", "yin", "yol"
]

male_suffix = [
    "ad", "aél", "an", "and", "ar", "ard", "as", "ath", "énd", "ër", "ern", "eth", "il", "in",
    "ind", "ion", "ir", "is", "ith", "lad", "läs", "lin", "lo", "lon", "or", "orn", "os", "rad",
    "rän", "ras", "rath", "rin", "ron", "ros", "rth", "th", "thir", "thor", "únd", "úr", "us",
    "win", "ynd", "yon", "ÿth"
]

surname_syllables = [
    "ael", "al", "an", "ar", "cal", "dael", "ël", "er", "fae", "fal", "fi", "gal", "gil", "glor",
    "hal", "ia", "id", "il", "im", "in", "laér", "lan", "leg", "li", "lind", "lith", "lor", "mae",
    "mel", "ne", "ner", "nén", "ner", "or", "pe", "ran", "rhöv", "sae", "sae", "se", "sil", "ta",
    "thal", "thar", "thing", "ti", "tir", "val", "vi", "yar", "zah", "zim"
]

female = generate_female_name(female_prefix, female_suffix, min=1, max=1)
male = generate_male_name(male_prefix, male_suffix, min=1, max=1)
surname = generate_surname(surname_syllables, min=2, max=3)
